pilas.ejemplos.ui

Package pilas :: Package ejemplos :: Module ui |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.ejemplos.ui

      1  # -*- coding: utf-8 -*-
      2
      3  # Form implementation generated from reading ui file 'ui.ui'
      4  #
      5  # Created: Sun Aug 26 14:47:38 2012
      6  #      by: PyQt4 UI code generator 4.9.1
      7  #
      8  # WARNING! All changes made in this file will be lost!
      9
     10  from PyQt4 import QtCore, QtGui
     11
     12  try:
     13      _fromUtf8 = QtCore.QString.fromUtf8
     14  except AttributeError:
     15      _fromUtf8 = lambda s: s
     16
     17 -class Ui_Ejemplos(object):
     18 -    def setupUi(self, Ejemplos):
     19          Ejemplos.setObjectName(_fromUtf8("Ejemplos"))
     20          Ejemplos.resize(787, 493)
     21          self.gridLayout = QtGui.QGridLayout(Ejemplos)
     22          self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
     23          self.splitter_2 = QtGui.QSplitter(Ejemplos)
     24          self.splitter_2.setOrientation(QtCore.Qt.Horizontal)
     25          self.splitter_2.setObjectName(_fromUtf8("splitter_2"))
     26          self.vbox_left = QtGui.QWidget(self.splitter_2)
     27          self.vbox_left.setObjectName(_fromUtf8("vbox_left"))
     28          self.vlayout_left = QtGui.QVBoxLayout(self.vbox_left)
     29          self.vlayout_left.setMargin(0)
     30          self.vlayout_left.setObjectName(_fromUtf8("vlayout_left"))
     31          self.arbol = QtGui.QTreeWidget(self.vbox_left)
     32          self.arbol.setObjectName(_fromUtf8("arbol"))
     33          self.arbol.headerItem().setText(0, _fromUtf8("1"))
     34          self.vlayout_left.addWidget(self.arbol)
     35          self.splitter = QtGui.QSplitter(self.splitter_2)
     36          self.splitter.setOrientation(QtCore.Qt.Vertical)
     37          self.splitter.setObjectName(_fromUtf8("splitter"))
     38          self.imagen = QtGui.QGraphicsView(self.splitter)
     39          sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Minimum)
     40          sizePolicy.setHorizontalStretch(0)
     41          sizePolicy.setVerticalStretch(0)
     42          sizePolicy.setHeightForWidth(self.imagen.sizePolicy().hasHeightForWidth())
     43          self.imagen.setSizePolicy(sizePolicy)
     44          self.imagen.setMinimumSize(QtCore.QSize(400, 300))
     45          self.imagen.setAutoFillBackground(True)
     46          self.imagen.setRenderHints(QtGui.QPainter.SmoothPixmapTransform)
     47          self.imagen.setTransformationAnchor(QtGui.QGraphicsView.AnchorUnderMouse)
     48          self.imagen.setResizeAnchor(QtGui.QGraphicsView.AnchorViewCenter)
     49          self.imagen.setViewportUpdateMode(QtGui.QGraphicsView.SmartViewportUpdate)
     50          self.imagen.setObjectName(_fromUtf8("imagen"))
     51          self.layoutWidget = QtGui.QWidget(self.splitter)
     52          self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
     53          self.verticalLayout = QtGui.QVBoxLayout(self.layoutWidget)
     54          self.verticalLayout.setMargin(0)
     55          self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
     56          self.progreso = QtGui.QFrame(self.layoutWidget)
     57          self.progreso.setMinimumSize(QtCore.QSize(0, 22))
     58          self.progreso.setFrameShape(QtGui.QFrame.NoFrame)
     59          self.progreso.setFrameShadow(QtGui.QFrame.Plain)
     60          self.progreso.setLineWidth(0)
     61          self.progreso.setObjectName(_fromUtf8("progreso"))
     62          self.label = QtGui.QLabel(self.progreso)
     63          self.label.setGeometry(QtCore.QRect(6, 0, 170, 21))
     64          self.label.setObjectName(_fromUtf8("label"))
     65          self.verticalLayout.addWidget(self.progreso)
     66          self.horizontalLayout = QtGui.QHBoxLayout()
     67          self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
     68          self.ejecutar = QtGui.QPushButton(self.layoutWidget)
     69          self.ejecutar.setObjectName(_fromUtf8("ejecutar"))
     70          self.horizontalLayout.addWidget(self.ejecutar)
     71          self.fuente = QtGui.QPushButton(self.layoutWidget)
     72          self.fuente.setObjectName(_fromUtf8("fuente"))
     73          self.horizontalLayout.addWidget(self.fuente)
     74          self.guardar = QtGui.QPushButton(self.layoutWidget)
     75          self.guardar.setObjectName(_fromUtf8("guardar"))
     76          self.horizontalLayout.addWidget(self.guardar)
     77          self.verticalLayout.addLayout(self.horizontalLayout)
     78          self.codigo = QtGui.QTextEdit(self.layoutWidget)
     79          self.codigo.setReadOnly(True)
     80          self.codigo.setObjectName(_fromUtf8("codigo"))
     81          self.verticalLayout.addWidget(self.codigo)
     82          self.gridLayout.addWidget(self.splitter_2, 0, 0, 1, 1)
     83
     84          self.retranslateUi(Ejemplos)
     85          QtCore.QMetaObject.connectSlotsByName(Ejemplos)
     86
     87 -    def retranslateUi(self, Ejemplos):
     88          Ejemplos.setWindowTitle(QtGui.QApplication.translate("Ejemplos", "Explorador de ejemplos", None, QtGui.QApplication.UnicodeUTF8))
     89          self.label.setText(QtGui.QApplication.translate("Ejemplos", "Aguarde por favor ...", None, QtGui.QApplication.UnicodeUTF8))
     90          self.ejecutar.setText(QtGui.QApplication.translate("Ejemplos", "Ejecutar", None, QtGui.QApplication.UnicodeUTF8))
     91          self.fuente.setText(QtGui.QApplication.translate("Ejemplos", "Cambiar tipografia", None, QtGui.QApplication.UnicodeUTF8))
     92          self.guardar.setText(QtGui.QApplication.translate("Ejemplos", "Guardar Codigo", None, QtGui.QApplication.UnicodeUTF8))
     93
     94
     95  if __name__ == "__main__":
     96      import sys
     97      app = QtGui.QApplication(sys.argv)
     98      Ejemplos = QtGui.QDialog()
     99      ui = Ui_Ejemplos()
    100      ui.setupUi(Ejemplos)
    101      Ejemplos.show()
    102      sys.exit(app.exec_())
    103